var expect = require('chai').expect;
var db = require('../../../db');
var ObjectId = require('mongodb').ObjectId;
var language = require('../../../models/language');

describe('language model tests', function() {
  var sampleLanguage;
  var sampleLanguages;
  
  before(function(done) {
    db.connect('mongodb://localhost/todotest', done);
  });
  
  after(function() {
    db.close();
  });
  
  var id = function(idValue) {
    return new ObjectId(idValue);
  }

  beforeEach(function(done) {
    sampleLanguage = {name: 'a new language', author: 'Some Author'};

    sampleLanguages = [
      {_id: id('123412341240'), name: 'lang 1', author: 'author 1'},
      {_id: id('123412341241'), name: 'lang 2', author: 'author 2'},
      {_id: id('123412341242'), name: 'lang 3', author: 'author 3'},
    ];
    
    db.get().collection('languages').insert(sampleLanguages, done);
  });
  
  afterEach(function() {
    db.get().collection('languages').drop();
  });  

  it('all should return all the languges', function(done) {
    var callback = function(err, languges) {
      expect(languges).to.be.eql(sampleLanguages);
      done();
    }
    
    language.all(callback);
  });
  
  it('add should return null for valid language', function(done) {
    var callback = function(err) {
      expect(err).to.be.null;
      language.all(function(err, languages) {
        expect(languages[3].name).to.be.eql('a new language');
        done();
      });
    }
  
    language.add(sampleLanguage, callback);
  });
   
  var expectError = function(message, done) {
    return function(err) {
      expect(err.message).to.be.eql(message);
      done();       
    };
  }
  
  it('add should return Error if task already exists', function(done) {
    sampleLanguage = sampleLanguages[0];
    delete sampleLanguage._id;
    language.add(sampleLanguage, expectError('duplicate not allowed', done));
  });
  
  it('delete should send null after deleting existing language', function(done) {
    var callback = function(err) {
      expect(err).to.be.null;
      language.all(function(err, languages) {
        expect(languages.length).to.be.eql(2);
        done();
      });
    }
    language.delete('123412341242', callback);    
  });

  it('delete should return Error if language not found', function(done) {
    language.delete('121212121212', 
      expectError('unable to delete language with id: 121212121212',
       done));
  });
  
});